==> datos_0.4.0.tar.gz: datos/data/data.R <==
delayedAssign('aerolineas',
        eval(parse(file.path(system.file('scripts','aerolineas.txt', package = 'datos')))))
delayedAssign('aeropuertos',
        eval(parse(file.path(system.file('scripts','aeropuertos.txt', package = 'datos')))))
delayedAssign('atmosfera',
        eval(parse(file.path(system.file('scripts','atmosfera.txt', package = 'datos')))))
delayedAssign('premios_dirigentes',
        eval(parse(file.path(system.file('scripts','premios_dirigentes.txt', package = 'datos')))))
delayedAssign('nombres',
        eval(parse(file.path(system.file('scripts','nombres.txt', package = 'datos')))))
delayedAssign('bateadores',
        eval(parse(file.path(system.file('scripts','bateadores.txt', package = 'datos')))))
delayedAssign('comunes',
        eval(parse(file.path(system.file('scripts','comunes.txt', package = 'datos')))))
delayedAssign('diamantes',
        eval(parse(file.path(system.file('scripts','diamantes.txt', package = 'datos')))))
delayedAssign('fiel',
        eval(parse(file.path(system.file('scripts','fiel.txt', package = 'datos')))))
delayedAssign('jardineros',
        eval(parse(file.path(system.file('scripts','jardineros.txt', package = 'datos')))))
delayedAssign('vuelos',
        eval(parse(file.path(system.file('scripts','vuelos.txt', package = 'datos')))))
delayedAssign('paises',
        eval(parse(file.path(system.file('scripts','paises.txt', package = 'datos')))))
delayedAssign('encuesta',
        eval(parse(file.path(system.file('scripts','encuesta.txt', package = 'datos')))))
delayedAssign('flores',
        eval(parse(file.path(system.file('scripts','flores.txt', package = 'datos')))))
delayedAssign('dirigentes',
        eval(parse(file.path(system.file('scripts','dirigentes.txt', package = 'datos')))))
delayedAssign('millas',
        eval(parse(file.path(system.file('scripts','millas.txt', package = 'datos')))))
delayedAssign('mtautos',
        eval(parse(file.path(system.file('scripts','mtautos.txt', package = 'datos')))))
delayedAssign('pinguinos',
        eval(parse(file.path(system.file('scripts','pinguinos.txt', package = 'datos')))))
delayedAssign('personas',
        eval(parse(file.path(system.file('scripts','personas.txt', package = 'datos')))))
delayedAssign('lanzadores',
        eval(parse(file.path(system.file('scripts','lanzadores.txt', package = 'datos')))))
delayedAssign('aviones',
        eval(parse(file.path(system.file('scripts','aviones.txt', package = 'datos')))))
delayedAssign('presidencial',
        eval(parse(file.path(system.file('scripts','presidencial.txt', package = 'datos')))))
delayedAssign('salarios',
        eval(parse(file.path(system.file('scripts','salarios.txt', package = 'datos')))))
delayedAssign('tabla1',
        eval(parse(file.path(system.file('scripts','tabla1.txt', package = 'datos')))))
delayedAssign('tabla2',
        eval(parse(file.path(system.file('scripts','tabla2.txt', package = 'datos')))))
delayedAssign('tabla3',
        eval(parse(file.path(system.file('scripts','tabla3.txt', package = 'datos')))))
delayedAssign('tabla4a',
        eval(parse(file.path(system.file('scripts','tabla4a.txt', package = 'datos')))))
delayedAssign('tabla4b',
        eval(parse(file.path(system.file('scripts','tabla4b.txt', package = 'datos')))))
delayedAssign('tabla5',
        eval(parse(file.path(system.file('scripts','tabla5.txt', package = 'datos')))))
delayedAssign('vehiculos',
        eval(parse(file.path(system.file('scripts','vehiculos.txt', package = 'datos')))))
delayedAssign('clima',
        eval(parse(file.path(system.file('scripts','clima.txt', package = 'datos')))))
delayedAssign('oms',
        eval(parse(file.path(system.file('scripts','oms.txt', package = 'datos')))))

==> datos_0.5.0.tar.gz: datos/data/data.R <==
delayedAssign('aerolineas',
        eval(parse(file.path(system.file('scripts','aerolineas.txt', package = 'datos')))))
delayedAssign('aeropuertos',
        eval(parse(file.path(system.file('scripts','aeropuertos.txt', package = 'datos')))))
delayedAssign('atmosfera',
        eval(parse(file.path(system.file('scripts','atmosfera.txt', package = 'datos')))))
delayedAssign('premios_dirigentes',
        eval(parse(file.path(system.file('scripts','premios_dirigentes.txt', package = 'datos')))))
delayedAssign('nombres',
        eval(parse(file.path(system.file('scripts','nombres.txt', package = 'datos')))))
delayedAssign('bateadores',
        eval(parse(file.path(system.file('scripts','bateadores.txt', package = 'datos')))))
delayedAssign('comunes',
        eval(parse(file.path(system.file('scripts','comunes.txt', package = 'datos')))))
delayedAssign('datos_credito',
        eval(parse(file.path(system.file('scripts','datos_credito.txt', package = 'datos')))))
delayedAssign('diamantes',
        eval(parse(file.path(system.file('scripts','diamantes.txt', package = 'datos')))))
delayedAssign('fiel',
        eval(parse(file.path(system.file('scripts','fiel.txt', package = 'datos')))))
delayedAssign('jardineros',
        eval(parse(file.path(system.file('scripts','jardineros.txt', package = 'datos')))))
delayedAssign('vuelos',
        eval(parse(file.path(system.file('scripts','vuelos.txt', package = 'datos')))))
delayedAssign('paises',
        eval(parse(file.path(system.file('scripts','paises.txt', package = 'datos')))))
delayedAssign('encuesta',
        eval(parse(file.path(system.file('scripts','encuesta.txt', package = 'datos')))))
delayedAssign('flores',
        eval(parse(file.path(system.file('scripts','flores.txt', package = 'datos')))))
delayedAssign('dirigentes',
        eval(parse(file.path(system.file('scripts','dirigentes.txt', package = 'datos')))))
delayedAssign('millas',
        eval(parse(file.path(system.file('scripts','millas.txt', package = 'datos')))))
delayedAssign('mtautos',
        eval(parse(file.path(system.file('scripts','mtautos.txt', package = 'datos')))))
delayedAssign('pinguinos',
        eval(parse(file.path(system.file('scripts','pinguinos.txt', package = 'datos')))))
delayedAssign('personas',
        eval(parse(file.path(system.file('scripts','personas.txt', package = 'datos')))))
delayedAssign('lanzadores',
        eval(parse(file.path(system.file('scripts','lanzadores.txt', package = 'datos')))))
delayedAssign('aviones',
        eval(parse(file.path(system.file('scripts','aviones.txt', package = 'datos')))))
delayedAssign('presidencial',
        eval(parse(file.path(system.file('scripts','presidencial.txt', package = 'datos')))))
delayedAssign('salarios',
        eval(parse(file.path(system.file('scripts','salarios.txt', package = 'datos')))))
delayedAssign('tabla1',
        eval(parse(file.path(system.file('scripts','tabla1.txt', package = 'datos')))))
delayedAssign('tabla2',
        eval(parse(file.path(system.file('scripts','tabla2.txt', package = 'datos')))))
delayedAssign('tabla3',
        eval(parse(file.path(system.file('scripts','tabla3.txt', package = 'datos')))))
delayedAssign('tabla4a',
        eval(parse(file.path(system.file('scripts','tabla4a.txt', package = 'datos')))))
delayedAssign('tabla4b',
        eval(parse(file.path(system.file('scripts','tabla4b.txt', package = 'datos')))))
delayedAssign('tabla5',
        eval(parse(file.path(system.file('scripts','tabla5.txt', package = 'datos')))))
delayedAssign('vehiculos',
        eval(parse(file.path(system.file('scripts','vehiculos.txt', package = 'datos')))))
delayedAssign('clima',
        eval(parse(file.path(system.file('scripts','clima.txt', package = 'datos')))))
delayedAssign('oms',
        eval(parse(file.path(system.file('scripts','oms.txt', package = 'datos')))))
